<?PHP

/*-----------------------------------------------------------------------------------*/
/*	Start Form Submit
/*-----------------------------------------------------------------------------------*/

header("Content-type: application/json");

// Setup WPDB
require_once("../../../../wp-config.php");
global $wpdb;

// If Submitted
if( isset( $_POST['id'] ) ){
	
	// Cache Vars
	$email = $wpdb->escape($_POST['email']);
	$agree = $wpdb->escape($_POST['agree']);
	$locker_id = $wpdb->escape($_POST['id']);
	$ip = $wpdb->escape($_SERVER['REMOTE_ADDR']);
	$time = date( 'Y-m-d H:i:s' );
	$return_error = 'false';
	$empty = false;
	
	// Check for blank / default fields
	// First name
	if( isset($_POST['firstname']) ){
		$first_name = $wpdb->escape($_POST['firstname']);
		if( $first_name == '' || $first_name == 'نام' ){
			$empty = true;
		}
	} else {
		$first_name = '';
	}
	
	// Last Name
	if( isset($_POST['lastname']) ){
		$last_name = $wpdb->escape($_POST['lastname']);
		if( $last_name == '' || $last_name == 'نام خانوادگی' ){
			$empty = true;
		}
	} else {
		$last_name = '';
	}
	
	// Phone Number
	if( isset($_POST['phone']) ){
		$phone = $wpdb->escape($_POST['phone']);
		if( $phone == '' || $phone == 'تلفن تماس' ){
			$empty = true;
		}
	} else {
		$phone = '';
	}
	
	// Return error if empty
	if( $empty == false ){
		
		// Check for valid email
		if( is_email($email) ){
				
			if( $agree == '1' ){
					
				// Get Options
				$tcsublocker_googl_enabled = get_option('tcsublocker-googl-enabled');
				$tcsublocker_api_key = get_option('tcsublocker-api-key');
				$tcsublocker_penalty = get_option('tcsublocker-penalty');
				$tcsublocker_subscribe_heading = get_option('tcsublocker-subscribe-heading');
				$tcsublocker_subscribe_message = get_option('tcsublocker-subscribe-message');
				$tcsublocker_optin_message = get_option('tcsublocker-optin-message');
				$tcsublocker_thankyou_message = get_option('tcsublocker-thankyou-message');
				$tcsublocker_download_message = get_option('tcsublocker-download-message');
				$tcsublocker_email_message = get_option('tcsublocker-email-message');
				
				// Configure key
				if($tcsublocker_api_key == '' || !isset($tcsublocker_api_key) ){
					$tcsublocker_api_key = NULL;
				}
				
				// Check if user already in DB
				$check = $wpdb->get_var($wpdb->prepare("SELECT COUNT(id) FROM ".$wpdb->prefix."tc_subscriber_lock WHERE email = %s", $email));
				
				// Only insert if not already in db
				if($check == 0){
				
					$wpdb->insert($wpdb->prefix.'tc_subscriber_lock', array(
						'email'	=> $email,
						'first_name' => $first_name,
						'last_name' => $last_name,
						'phone_number' => $phone,
						'time' => $time,
						'ip' => $ip,
						'status' => 'pending' 
					));
							
				}
		
				// Setup URL
				$baseUrl = TCSUBLOCKER_LOCATION . '/inc/verify.php?1='.$locker_id.'&2='.base64_encode($email);
				if($tcsublocker_googl_enabled == 'true'){
					
					$sendUrl = tcsublocker_googl($baseUrl, $tcsublocker_api_key);
					
				} else {
					
					$sendUrl = $baseUrl;
					
				}
				
				// Sendmail
				$admin_email = get_bloginfo('admin_email');
				$admin_name = get_bloginfo('name');
				$subject = 'You\'re Verification Link';
				$headers = 'From: '.$admin_name.' <'.$admin_email.'>' . "\r\n";
				//$message = nl2br($tcsublocker_email_message);
				$message = "Hey there,\n\nHere is the verfication link you requested:\n\n$sendUrl\n\nAfter clicking this link all subscriber content will be unlocked for you, and you will not need to enter your email address anymore on the site.\n\nThanks again and enjoy!";
				mail($email, $subject, $message, $headers);
				
				// Set Waiting Cookie With Penalty Time
				$wait = time() + ( $tcsublocker_penalty * 60 );
				setcookie("tcel_glb", 'waiting', $wait, "/");	
				// Set Redirect Cookie
				setcookie('tcel_to', $_SERVER['HTTP_REFERER'], time()+999999, '/');
				
				// Return Success
				$return_msg = '<span class="tcsublocker-success">'.$tcsublocker_thankyou_message.'</span>';
				
			} else {
				
				// Return no opt-in error
				$return_msg = '<span class="tcsublocker-error">You must check that you agree to receive our newsletter before viewing content.</span>';
				$return_error = 'true';
				
			}
		
		} else { // else email not valid
			
			// return bad email error
			$return_msg = '<span class="tcsublocker-error">Whoa There! That email address is not valid.</span>';
			$return_error = 'true';
			
		} // end if email valid
	
	} else { // else form fields empty
		
		// return empty error
		$return_msg = '<span class="tcsublocker-error">Please make sure you have filled out all form fields.</span>';
		$return_error = 'true';
		
	}// end if empty / default

/*-----------------------------------------------------------------------------------*/
/*	Return to Frontend
/*-----------------------------------------------------------------------------------*/

	$return = array('message' => $return_msg, 'error' => $return_error);
	echo json_encode($return);

} // end if submitted

/*-----------------------------------------------------------------------------------*/
/*	Make URL Short
/*-----------------------------------------------------------------------------------*/

function tcsublocker_googl($long, $apiKey = NULL){
	
	$parameters = '{"longUrl": "' . $long . '"}';
	$url = 'https://www.googleapis.com/urlshortener/v1/url';
	
	if (!is_null($apiKey)) {
		$url .= '?key=' . $apiKey;
	}

	$curl = curl_init();
	curl_setopt($curl, CURLOPT_SSLVERSION, 3);
	curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 2);
	curl_setopt($curl, CURLOPT_HEADER, false);
	curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
	curl_setopt($curl, CURLOPT_POST, true);
	curl_setopt($curl, CURLOPT_POSTFIELDS, $parameters);
	curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-type: application/json'));
	curl_setopt($curl, CURLOPT_URL, $url);
	$data = json_decode(curl_exec($curl));
	curl_close($curl);
	
	return $data->id;
	
}

?>